import {parser} from "./src/parser.js"
import {foldNodeProp, foldInside, indentNodeProp, LRLanguage, LanguageSupport} from "@codemirror/language"
import {completeFromList} from '@codemirror/autocomplete'
import {styleTags, tags as Tag} from "@lezer/highlight"

const augmentedParser = parser.configure({
    props: [
        styleTags({
            Identifier: Tag.name,
            SystemIdentifier: Tag.macroName,
            UnsignedNumber: Tag.number,
            RealNumber: Tag.number,
            DecimalValue: Tag.integer,
            BinaryValue: Tag.integer,
            OctalValue: Tag.integer,
            HexValue: Tag.integer,
            BlockComment: Tag.blockComment,
            LineComment: Tag.lineComment,
            '( )': Tag.paren,
            '"module"': Tag.moduleKeyword,
            '"input"': Tag.moduleKeyword,
            '"ouput"': Tag.moduleKeyword,
            '"inout"': Tag.moduleKeyword,
            '(* *)': Tag.paren,
            'AttrSpec/...': Tag.meta
        })
    ]
})

export const verilogLanguage = LRLanguage.define({
    parser: augmentedParser
})

export const verilogCompletion = verilogLanguage.data.of({
    autocomplete: completeFromList([
        { label: 'module', type: 'keyword' }
    ])
})

export function verilog() {
    return new LanguageSupport(verilogLanguage, [verilogCompletion]);
}